@@ -161,8 +161,10 @@ class LHSQueryParser(QueryParser):
         for col in self._valid_columns:
             available_operators = self._available_operators_factory(col)
             default_operator = self._default_operator_factory(col)
-            available_operators_str = ", ".join(
-                f"`{op.value}`" for op in available_operators
+            available_operators_str = (
+                ", ".join(f"`{op.value}`" for op in available_operators)
+                if set(available_operators) != set(FiltrationOperator)
+                else "`*`"
             )
 
             param = inspect.Parameter(
